@@ -1,6 +1,6 @@
 import os
 import shutil
-
+from git import Repo
 
 def f1(data):
     i = 0
@@ -13,6 +13,19 @@ def f1(data):
             return i, vf
         i += 1
     raise Exception()
+def list_all_files(path):
+    if os.path.isfile(path):
+        return [path]
+    ans=list()
+    for p2 in os.listdir(path):
+        ans.extend(list_all_files(os.path.join(path,p2)))
+    return ans
+
+def commit(repo,message,folders_to_commit):
+    for p in folders_to_commit:
+        for f in list_all_files(p):
+            repo.index.add(f)
+    Repo().index.commit(message)
 if __name__=="__main__":
     print("main")
     #remove dist
@@ -30,6 +43,10 @@ if __name__=="__main__":
     with open(filename,"w") as f:
         f.writelines(data)
 
+    #commit
+    repo = Repo()
+    commit(repo, "c "+str(v), ["tests","testy_quick",'do_all.py', 'LICENSE', 'README.md', 'requirements.txt', 'setup.cfg', 'setup.py'])
+
     #build
     from setuptools import setup
     setup(script_args=["sdist","bdist_wheel"])
